import { NextResponse } from "next/server"
import { prisma } from "@/lib/prisma"

export async function POST(request: Request) {
  try {
    const body = await request.json()
    const { userId, examType, examId, score, maxScore, answers } = body

    // Vérifier si l'utilisateur existe
    const user = await prisma.user.findUnique({
      where: { id: userId },
    })

    if (!user) {
      return NextResponse.json({ error: "User not found" }, { status: 404 })
    }

    // Créer le score
    const newScore = await prisma.score.create({
      data: {
        userId,
        examType,
        examId,
        score,
        maxScore,
        passedAt: new Date(),
      },
    })

    return NextResponse.json(newScore, { status: 201 })
  } catch (error) {
    console.error("Error saving score:", error)
    return NextResponse.json({ error: "Failed to save score" }, { status: 500 })
  }
}
